@@ -76,9 +76,9 @@ class ChainRequestHandler(ExtRequestHandler):
             else:
                 validated = None
             incoming = InputContext(req, validated, prot_identity, kwargs)
-            if self.addons_loader:
-                plugins = await self.addons_loader.find_middleware_by_target(target.__name__)
-                for plugin in await self.addons_loader.find_middleware_by_target(target.__name__):
+            if hasattr(req.app.ctx.container, "addon_loader") and req.app.ctx.container.addon_loader.initialized:
+                plugins = await req.app.ctx.container.addon_loader().find_addon_by_target(target.__name__)
+                for plugin in await req.app.ctx.container.addon_loader().find_addon_by_target(target.__name__):
                     await plugin.exec_before(context=incoming, container=self.container)
                 if not plugins:
                     ret_val = await target(incoming, self.container)
